__title__ = "gemma-template"
__description__ = "Gemma Template is a lightweight Python library for generating templates to fine-tune models like Gemma, LLaMa, and others. It supports multilingual frameworks, offers advanced customization, and ensures precise, dynamic template creation."
__url__ = "https://github.com/thewebscraping/gemma-template"
__author__ = "Tu Pham"
__author_email__ = "thetwofarm@gmail.com"
__version__ = "0.1.5"
__license__ = "Apache-2.0"
